@@ -55,6 +55,15 @@ logger = logging.getLogger(__name__)
 
 dd_trace_context = {}
 dd_tracing_enabled = os.environ.get("DD_TRACE_ENABLED", "false").lower() == "true"
+if dd_tracing_enabled:
+    # Enable the telemetry client if the user has opted in
+    if (
+        os.environ.get("DD_INSTRUMENTATION_TELEMETRY_ENABLED", "false").lower()
+        == "true"
+    ):
+        from ddtrace.internal.telemetry import telemetry_writer
+
+        telemetry_writer.enable()
 
 propagator = HTTPPropagator()
 
